==> mule-artifact-ast-1.1.0.jar: module-info.java <==
module org.mule.runtime.artifact.ast {
    requires java.transaction.xa;
    requires org.mule.runtime.api.annotations;
    requires org.mule.runtime.api;
    requires org.mule.runtime.extensions.api;
    requires org.mule.runtime.metadata.model.api;
    requires org.mule.runtime.metadata.model.java;
    requires org.mule.runtime.dsl.api;
    requires org.mule.sdk.api;
    requires com.github.benmanes.caffeine;
    requires com.google.common;
    requires org.apache.commons.lang3;

    exports org.mule.runtime.ast.api;
    exports org.mule.runtime.ast.api.builder;
    exports org.mule.runtime.ast.api.error;
    exports org.mule.runtime.ast.api.exception;
    exports org.mule.runtime.ast.api.util;
    exports org.mule.runtime.ast.api.validation;
    exports org.mule.runtime.ast.internal to org.mule.runtime.artifact.ast.dependency.graph, org.mule.runtime.artifact.ast.xmlParser, org.mule.runtime.artifact.cfg, org.mule.runtime.spring.config, org.mule.runtime.artifact.ast.test, org.mule.runtime.artifact.ast.xmlParser.test;
    exports org.mule.runtime.ast.internal.validation to org.mule.runtime.artifact.ast.test;
    exports org.mule.runtime.ast.internal.builder to org.mule.runtime.artifact.ast.dependency.graph, org.mule.runtime.artifact.ast.xmlParser, org.mule.runtime.artifact.ast.serialization, org.mule.runtime.artifact.cfg, org.mule.runtime.artifact.ast.test, org.mule.runtime.artifact.ast.xmlParser.test, org.mule.runtime.artifact.ast.serialization.test;
    exports org.mule.runtime.ast.internal.builder.adapter to org.mule.runtime.artifact.ast.serialization, org.mule.runtime.artifact.ast.test;
    exports org.mule.runtime.ast.internal.error to org.mule.runtime.artifact.ast.xmlParser, org.mule.runtime.artifact.ast.serialization, org.mule.runtime.artifact.cfg, org.mule.runtime.extension.model, org.mule.runtime.artifact.ast.test, org.mule.runtime.artifact.ast.serialization.test;
    exports org.mule.runtime.ast.internal.model to org.mule.runtime.artifact.ast.xmlParser, org.mule.runtime.artifact.ast.serialization, org.mule.runtime.artifact.cfg, org.mule.runtime.extensions.mule.support, org.mule.runtime.artifact.ast.test, org.mule.runtime.artifact.ast.xmlParser.test, org.mule.runtime.artifact.ast.serialization.test;

}

==> mule-artifact-ast-1.2.0-rc1.jar: module-info.java <==
module org.mule.runtime.artifact.ast {
    requires java.transaction.xa;
    requires org.mule.runtime.api.annotations;
    requires org.mule.runtime.api;
    requires org.mule.runtime.extensions.api;
    requires org.mule.runtime.metadata.model.api;
    requires org.mule.runtime.metadata.model.java;
    requires org.mule.runtime.dsl.api;
    requires org.mule.sdk.api;
    requires com.github.benmanes.caffeine;
    requires com.google.common;
    requires org.apache.commons.lang3;

    exports org.mule.runtime.ast.api;
    exports org.mule.runtime.ast.api.builder;
    exports org.mule.runtime.ast.api.error;
    exports org.mule.runtime.ast.api.exception;
    exports org.mule.runtime.ast.api.util;
    exports org.mule.runtime.ast.api.validation;
    exports org.mule.runtime.ast.privileged.error;
    exports org.mule.runtime.ast.internal to org.mule.runtime.artifact.ast.dependency.graph, org.mule.runtime.artifact.ast.xmlParser, org.mule.runtime.artifact.cfg, org.mule.runtime.spring.config, org.mule.runtime.artifact.ast.test, org.mule.runtime.artifact.ast.xmlParser.test;
    exports org.mule.runtime.ast.internal.validation to org.mule.runtime.spring.config, org.mule.runtime.artifact.ast.test;
    exports org.mule.runtime.ast.internal.builder to org.mule.runtime.artifact.ast.dependency.graph, org.mule.runtime.artifact.ast.xmlParser, org.mule.runtime.artifact.ast.serialization, org.mule.runtime.artifact.cfg, org.mule.runtime.artifact.ast.test, org.mule.runtime.artifact.ast.xmlParser.test, org.mule.runtime.artifact.ast.serialization.test;
    exports org.mule.runtime.ast.internal.builder.adapter to org.mule.runtime.artifact.ast.serialization, org.mule.runtime.artifact.ast.test;
    exports org.mule.runtime.ast.internal.error to org.mule.runtime.artifact.ast.xmlParser, org.mule.runtime.artifact.ast.serialization, org.mule.runtime.artifact.cfg, org.mule.runtime.extension.model, org.mule.runtime.extensions.support, org.mule.runtime.artifact.ast.test, org.mule.runtime.artifact.ast.serialization.test;
    exports org.mule.runtime.ast.internal.model to org.mule.runtime.artifact.ast.xmlParser, org.mule.runtime.artifact.ast.serialization, org.mule.runtime.artifact.cfg, org.mule.runtime.extensions.mule.support, org.mule.runtime.artifact.ast.test, org.mule.runtime.artifact.ast.xmlParser.test, org.mule.runtime.artifact.ast.serialization.test;

    opens org.mule.runtime.ast.privileged.error to kryo.shaded;

}
